// Пример для одного звукоизлучателя:                                                  //
#include <Wire.h>                                                                      // Подключаем библиотеку Wire. Для работы с Arduino/Piranha, эту библиотеку можно не подключать.
#include <iarduino_Metro.h>                                                            // Подключаем библиотеку.
                                                                                       //
uint8_t sum;                                                                           // Объявляем переменную для хранения количества найденных модулей Metro.
                                                                                       //
void setup(){                                                                          //
//  Определяем все модули на шине I2C и сохраняем их количество в переменную sum:      //
    sum=iarduino_Metro_Start();                                                        // В качестве аргумента функции iarduino_Metro_Start() можно указать номер адресного вывода (если вывод не указан, то будет использован D12).
//  Теперь нам доступен массив Metro содержащий sum элементов для управления модулями. // Metro[0] управляет ближайшим к Arduino модулем, Metro[1] управляет следующим модулем и т.д до последнего модуля Metro[sum-1].
                                                                                       //
//  Проверяем наличие модулей Metro на шине I2C:                                       //
    while(sum==0){;}                                                                   // Если модули Metro не обнаружены, то входим в бесконечный цикл while, тогда цикл loop выполняться не будет.
    while(Metro[0].model!=MOD_BUZ){;}                                                  // Если ближайший к Arduino модуль Metro не является звукоизлучателем, то так же входим в бесконечный цикл while.
                                                                                       //
//  Включаем тональный сигнал (частота по умолчанию 3 кГц):                            //
    Metro[0].on();                                                                     // Включаем звукоизлучатель без указания частоты тонального сигнала (по умолчанию установится звук с частотой 3000 Гц).
    delay(3000);                                                                       // Ждём 3 секунды.
    Metro[0].off();                                                                    // Выключаем звукоизлучатель.
    delay(1000);                                                                       // Ждём 1 секунду.
//  Включаем звукоизлучатель с указанием частоты тонального сигнала:                   //
    Metro[0].on( 2000 );                                                               // Включаем звук с частотой 2000 Гц.
    delay(3000);                                                                       // Ждём 3 секунды.
    Metro[0].off();                                                                    // Выключаем светодиод.
    delay(1000);                                                                       // Ждём 1 секунду.
//  Включаем звукоизлучатель на определённое время (будет включён 1000 миллисекунд):   //
    Metro[0].on( 3500, 1000);                                                          // Включаем звук с частотой 3500 Гц на 1000 мс (1 сек) после чего звук выключится.
    delay(3000);                                                                       // Ждём 3 секунды (так как звук будет издаваться только 1 секунду, то оставшиеся 2 секунды ожидания он звукоизлучатель будет выключен).
//  Заставляем звукоизлучатель постоянно воспроизводить тональные сигналы:             //
    Metro[0].on( 2500, 100, 200);                                                      // Издаём тональные сигналы с частотой 2,5 кГц, длительность сигнала 100 мс и пауза между сигналами 200 мс.
    delay(3000);                                                                       // Ждём 3 секунды.
//  Заставляем звукоизлучатель воспроизвести 3 тональных сигнала и выключиться:        //
    Metro[0].on( 3500, 100, 200, 3);                                                   // Издаём тональные сигналы с частотой 3,5 кГц, длительность сигнала 100 мс, пауза между сигналами 200 мс, количество сигналов = 3.
}                                                                                      //
                                                                                       //
void loop(){                                                                           //
/*                                                                                     //
 *   Metro[0].on(); - включить звук без указания частоты.                              // Если частота не указана, то звукоизлучатель будет воспроизводить звук на частоте 3 кГц.
 *   Metro[0].on( частота ); - включить звук на указанной частоте.                     // Звукоизлучатель будет издавать звук пока не получит новую команду, например, на отключение звука. Частота указывается в Гц, от 10 до 10000 Гц.
 *   Metro[0].on( частота , длительность ); - включить звук на указанное время.        // Звукоизлучатель будет издавать звук в течении указанной длительности в миллисекундах от 0 до 25500 мс, например, 1000 - издавать звук 1 секунду после чего выключиться.
 *   Metro[0].on( частота , длительность , пауза ); - издавать звуковые сигналы.       // Звукоизлучатель будет издавать звуковые сигналы, длительность сигналов и паузы между ними указываются в миллисекундах от 0 до 25500 мс.
 *   Metro[0].on( частота , длительность , пауза , количество ); -издать неск.сигналов.// Звукоизлучатель издаст звуковые сигналы указанной частоты, длительности и паузы, указанное количество раз от 1 до 255.
 *   Metro[0].off(); - выключить звук                                                  // 
 */                                                                                    //
}                                                                                      //